==> v5.0.zip: luckperms/api/src/main/java/net/luckperms/api/event/track/mutate/TrackMutateEvent.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package net.luckperms.api.event.track.mutate;

import net.luckperms.api.event.LuckPermsEvent;
import net.luckperms.api.event.util.Param;
import net.luckperms.api.track.Track;

import org.checkerframework.checker.nullness.qual.NonNull;

import java.util.List;

/**
 * Called when a track is changed
 */
public interface TrackMutateEvent extends LuckPermsEvent {

    /**
     * Gets the track that was mutated
     *
     * @return the track that was mutated
     */
    @Param(0)
    @NonNull Track getTrack();

    /**
     * Gets an immutable copy of the tracks data before the change
     *
     * @return the data before the change
     */
    @Param(1)
    @NonNull List<String> getStateBefore();

    /**
     * Gets an immutable copy of the tracks data after the change
     *
     * @return the data after the change
     */
    @Param(2)
    @NonNull List<String> getStateAfter();

}

==> v5.3.zip: luckperms/api/src/main/java/net/luckperms/api/event/track/mutate/TrackMutateEvent.java <==
/*
 * This file is part of LuckPerms, licensed under the MIT License.
 *
 *  Copyright (c) lucko (Luck) <luck@lucko.me>
 *  Copyright (c) contributors
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 */

package net.luckperms.api.event.track.mutate;

import net.luckperms.api.event.LuckPermsEvent;
import net.luckperms.api.event.util.Param;
import net.luckperms.api.track.Track;

import org.checkerframework.checker.nullness.qual.NonNull;
import org.jetbrains.annotations.Unmodifiable;

import java.util.List;

/**
 * Called when a track is changed
 */
public interface TrackMutateEvent extends LuckPermsEvent {

    /**
     * Gets the track that was mutated
     *
     * @return the track that was mutated
     */
    @Param(0)
    @NonNull Track getTrack();

    /**
     * Gets an immutable copy of the tracks data before the change
     *
     * @return the data before the change
     */
    @Param(1)
    @NonNull @Unmodifiable List<String> getStateBefore();

    /**
     * Gets an immutable copy of the tracks data after the change
     *
     * @return the data after the change
     */
    @Param(2)
    @NonNull @Unmodifiable List<String> getStateAfter();

}
